@@ -32,13 +32,15 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ARC4_DECRYPTOR_H_
-#define _D_ARC4_DECRYPTOR_H_
+#ifndef D_ARC4_DECRYPTOR_H
+#define D_ARC4_DECRYPTOR_H
 
 #include "common.h"
-#ifdef HAVE_LIBGCRYPT
+#ifdef HAVE_LIBNETTLE
+# include "LibnettleARC4Decryptor.h"
+#elif HAVE_LIBGCRYPT
 # include "LibgcryptARC4Decryptor.h"
-#elif HAVE_LIBSSL
+#elif HAVE_OPENSSL
 # include "LibsslARC4Decryptor.h"
 #else
 
@@ -62,4 +64,4 @@ public:
 
 #endif
 
-#endif // _D_ARC4_DECRYPTOR_H_
+#endif // D_ARC4_DECRYPTOR_H
