@@ -32,23 +32,31 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ABSTRACT_COMMAND_H_
-#define _D_ABSTRACT_COMMAND_H_
+#ifndef D_ABSTRACT_COMMAND_H
+#define D_ABSTRACT_COMMAND_H
 
 #include "Command.h"
+
+#include <vector>
+#include <string>
+
 #include "SharedHandle.h"
 #include "TimerA2.h"
-#include "FileEntry.h"
-#include "RequestGroup.h"
 
 namespace aria2 {
 
+class FileEntry;
+class RequestGroup;
+class CheckIntegrityEntry;
+class DownloadContext;
+class SegmentMan;
+class PieceStorage;
 class Request;
 class DownloadEngine;
 class Segment;
-class Exception;
 class SocketCore;
 class Option;
+class SocketRecvBuffer;
 #ifdef ENABLE_ASYNC_DNS
 class AsyncNameResolver;
 #endif // ENABLE_ASYNC_DNS
@@ -63,6 +71,7 @@ private:
   SharedHandle<FileEntry> fileEntry_;
   DownloadEngine* e_;
   SharedHandle<SocketCore> socket_;
+  SharedHandle<SocketRecvBuffer> socketRecvBuffer_;
   std::vector<SharedHandle<Segment> > segments_;
 
 #ifdef ENABLE_ASYNC_DNS
@@ -75,6 +84,11 @@ private:
   SharedHandle<SocketCore> writeCheckTarget_;
   bool nameResolverCheck_;
 
+  bool incNumConnection_;
+  Timer serverStatTimer_;
+
+  size_t calculateMinSplitSize() const;
+  void useFasterRequest(const SharedHandle<Request>& fasterRequest);
 #ifdef ENABLE_ASYNC_DNS
   void setNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver);
 
@@ -94,20 +108,14 @@ protected:
     return req_;
   }
 
-  void setRequest(const SharedHandle<Request>& request)
-  {
-    req_ = request;
-  }
+  void setRequest(const SharedHandle<Request>& request);
 
   const SharedHandle<FileEntry>& getFileEntry() const
   {
     return fileEntry_;
   }
 
-  void setFileEntry(const SharedHandle<FileEntry>& fileEntry)
-  {
-    fileEntry_ = fileEntry;
-  }
+  void setFileEntry(const SharedHandle<FileEntry>& fileEntry);
 
   DownloadEngine* getDownloadEngine() const
   {
@@ -119,13 +127,15 @@ protected:
     return socket_;
   }
 
-  void setSocket(const SharedHandle<SocketCore>& s)
-  {
-    socket_ = s;
-  }
+  void setSocket(const SharedHandle<SocketCore>& s);
 
   void createSocket();
 
+  const SharedHandle<SocketRecvBuffer>& getSocketRecvBuffer() const
+  {
+    return socketRecvBuffer_;
+  }
+
   const std::vector<SharedHandle<Segment> >& getSegments() const
   {
     return segments_;
@@ -170,9 +180,15 @@ protected:
    */
   void setWriteCheckSocketIf(const SharedHandle<SocketCore>& socket, bool pred);
 
+  time_t getTimeout() const
+  {
+    return timeout_;
+  }
+
   void setTimeout(time_t timeout) { timeout_ = timeout; }
 
-  void prepareForNextAction(Command* nextCommand = 0);
+  void prepareForNextAction
+  (const SharedHandle<CheckIntegrityEntry>& checkEntry);
 
   // Check if socket is connected. If socket is not connected and
   // there are other addresses to try, command is created using
@@ -203,25 +219,25 @@ protected:
 
   const SharedHandle<Option>& getOption() const;
 
-  const SharedHandle<DownloadContext>& getDownloadContext() const
+  const SharedHandle<DownloadContext>& getDownloadContext() const;
+  const SharedHandle<SegmentMan>& getSegmentMan() const;
+  const SharedHandle<PieceStorage>& getPieceStorage() const;
+
+  Timer& getCheckPoint()
   {
-    return requestGroup_->getDownloadContext();
+    return checkPoint_;
   }
 
-  const SharedHandle<SegmentMan>& getSegmentMan() const
-  {
-    return requestGroup_->getSegmentMan();
-  }
-
-  const SharedHandle<PieceStorage>& getPieceStorage() const
-  {
-    return requestGroup_->getPieceStorage();
-  }
+  void checkSocketRecvBuffer();
 public:
-  AbstractCommand(cuid_t cuid, const SharedHandle<Request>& req,
-                  const SharedHandle<FileEntry>& fileEntry,
-                  RequestGroup* requestGroup, DownloadEngine* e,
-                  const SharedHandle<SocketCore>& s = SharedHandle<SocketCore>());
+  AbstractCommand
+  (cuid_t cuid, const SharedHandle<Request>& req,
+   const SharedHandle<FileEntry>& fileEntry,
+   RequestGroup* requestGroup, DownloadEngine* e,
+   const SharedHandle<SocketCore>& s = SharedHandle<SocketCore>(),
+   const SharedHandle<SocketRecvBuffer>& socketRecvBuffer
+   = SharedHandle<SocketRecvBuffer>(),
+   bool incNumConnection = true);
 
   virtual ~AbstractCommand();
   bool execute();
@@ -229,4 +245,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_ABSTRACT_COMMAND_H_
+#endif // D_ABSTRACT_COMMAND_H
