@@ -41,9 +41,16 @@
 #include "BtRuntime.h"
 #include "BtProgressInfoFile.h"
 #include "bittorrent_helper.h"
+#include "LpdMessageReceiver.h"
 
 namespace aria2 {
 
+BtRegistry::BtRegistry()
+  : tcpPort_(0)
+{}
+
+BtRegistry::~BtRegistry() {}
+
 SharedHandle<DownloadContext>
 BtRegistry::getDownloadContext(a2_gid_t gid) const
 {
@@ -89,6 +96,12 @@ void BtRegistry::removeAll() {
   pool_.clear();
 }
 
+void BtRegistry::setLpdMessageReceiver
+(const SharedHandle<LpdMessageReceiver>& receiver)
+{
+  lpdMessageReceiver_ = receiver;
+}
+
 BtObject::BtObject
 (const SharedHandle<DownloadContext>& downloadContext,
  const SharedHandle<PieceStorage>& pieceStorage,
