@@ -404,9 +404,10 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
       getPieceStorage()->markAllPiecesDone();
       getDownloadContext()->setChecksumVerified(true);
       sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
-      A2_LOG_NOTICE(fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                        util::itos(getRequestGroup()->getGID()).c_str(),
-                        getRequestGroup()->getFirstFilePath().c_str()));
+      A2_LOG_NOTICE
+        (fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
+             util::itos(getRequestGroup()->getGID()).c_str(),
+             getRequestGroup()->getFirstFilePath().c_str()));
       poolConnection();
 
       return false;
