@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_HEADER_H_
-#define _D_HTTP_HEADER_H_
+#ifndef D_HTTP_HEADER_H
+#define D_HTTP_HEADER_H
 
 #include "common.h"
 
@@ -52,9 +52,8 @@ class HttpHeader {
 private:
   std::multimap<std::string, std::string> table_;
 
-  // for HTTP response header only
-  // response status, e.g. "200"
-  std::string responseStatus_;
+  // HTTP status code, e.g. 200
+  int statusCode_;
 
   // HTTP version, e.g. HTTP/1.1
   std::string version_;
@@ -65,24 +64,30 @@ private:
   // Request Path
   std::string requestPath_;
 public:
-  HttpHeader() {}
-  ~HttpHeader() {}
+  HttpHeader();
+  ~HttpHeader();
 
   void put(const std::string& name, const std::string& value);
   bool defined(const std::string& name) const;
   const std::string& getFirst(const std::string& name) const;
   std::vector<std::string> get(const std::string& name) const;
+  std::pair<std::multimap<std::string, std::string>::const_iterator,
+            std::multimap<std::string, std::string>::const_iterator>
+  getIterator(const std::string& name) const;
   unsigned int getFirstAsUInt(const std::string& name) const;
   uint64_t getFirstAsULLInt(const std::string& name) const;
 
   SharedHandle<Range> getRange() const;
 
-  const std::string& getResponseStatus() const
+  int getStatusCode() const
   {
-    return responseStatus_;
+    return statusCode_;
   }
 
-  void setResponseStatus(const std::string& responseStatus);
+  void setStatusCode(int code)
+  {
+    statusCode_ = code;
+  }
 
   const std::string& getVersion() const
   {
@@ -120,20 +125,12 @@ public:
   
   static const std::string SET_COOKIE;
   
-  static const std::string CHUNKED;
-  
-  static const std::string GZIP;
-
-  static const std::string DEFLATE;
-
   static const std::string CONTENT_TYPE;
   
   static const std::string RETRY_AFTER;
   
   static const std::string CONNECTION;
 
-  static const std::string CLOSE;
-
   static const std::string CONTENT_LENGTH;
 
   static const std::string CONTENT_RANGE;
@@ -142,21 +139,23 @@ public:
 
   static const std::string ACCEPT_ENCODING;
 
-  static const std::string HTTP_1_1;
+  static const std::string LINK;
 
-  static const std::string S200;
+  static const std::string DIGEST;
 
-  static const std::string S300;
+  static const char HTTP_1_1[];
 
-  static const std::string S400;
+  static const char CLOSE[];
 
-  static const std::string S401;
+  static const char CHUNKED[];
   
-  static const std::string S404;
+  static const char GZIP[];
+
+  static const char DEFLATE[];
 };
 
 typedef SharedHandle<HttpHeader> HttpHeaderHandle;
 
 } // namespace std;
 
-#endif // _D_HTTP_HEADER_H_
+#endif // D_HTTP_HEADER_H
