@@ -72,6 +72,10 @@
 #include "ChunkedDecodingStreamFilter.h"
 #include "uri.h"
 #include "SocketRecvBuffer.h"
+#include "MetalinkHttpEntry.h"
+#ifdef ENABLE_MESSAGE_DIGEST
+#include "Checksum.h"
+#endif // ENABLE_MESSAGE_DIGEST
 #ifdef HAVE_ZLIB
 # include "GZipDecodingStreamFilter.h"
 #endif // HAVE_ZLIB
@@ -182,13 +186,49 @@ bool HttpResponseCommand::executeInternal()
     getPieceStorage()->markAllPiecesDone();
     // Just set checksum verification done.
     getDownloadContext()->setChecksumVerified(true);
-    A2_LOG_NOTICE(fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                      util::itos(getRequestGroup()->getGID()).c_str(),
-                      getRequestGroup()->getFirstFilePath().c_str()));
+    A2_LOG_NOTICE
+      (fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
+           util::itos(getRequestGroup()->getGID()).c_str(),
+           getRequestGroup()->getFirstFilePath().c_str()));
     poolConnection();
     getFileEntry()->poolRequest(getRequest());
     return true;
   }
+  if(!getPieceStorage()) {
+    // Metalink/HTTP
+    if(!getDownloadContext()->getMetalinkServerContacted()) {
+      if(httpHeader->defined(HttpHeader::LINK)) {
+        getDownloadContext()->setMetalinkServerContacted(true);
+        std::vector<MetalinkHttpEntry> entries;
+        httpResponse->getMetalinKHttpEntries(entries, getOption());
+        for(std::vector<MetalinkHttpEntry>::iterator i = entries.begin(),
+              eoi = entries.end(); i != eoi; ++i) {
+          getFileEntry()->addUri((*i).uri);
+          A2_LOG_DEBUG(fmt("Adding URI=%s", (*i).uri.c_str()));
+        }
+      }
+    }
+#ifdef ENABLE_MESSAGE_DIGEST
+    if(httpHeader->defined(HttpHeader::DIGEST)) {
+      std::vector<Checksum> checksums;
+      httpResponse->getDigest(checksums);
+      for(std::vector<Checksum>::iterator i = checksums.begin(),
+            eoi = checksums.end(); i != eoi; ++i) {
+        if(getDownloadContext()->getHashType().empty()) {
+          A2_LOG_DEBUG(fmt("Setting digest: type=%s, digest=%s",
+                           (*i).getHashType().c_str(),
+                           (*i).getDigest().c_str()));
+          getDownloadContext()->setDigest((*i).getHashType(), (*i).getDigest());
+          break;
+        } else {
+          if(checkChecksum(getDownloadContext(), *i)) {
+            break;
+          }
+        }
+      }
+    }
+#endif // ENABLE_MESSAGE_DIGEST
+  }
   if(statusCode >= 300) {
     if(statusCode == 404) {
       getRequestGroup()->increaseAndValidateFileNotFoundCount();
@@ -204,6 +244,7 @@ bool HttpResponseCommand::executeInternal()
     }
   }
   if(!getPieceStorage()) {
+    util::removeMetalinkContentTypes(getRequestGroup());
     uint64_t totalLength = httpResponse->getEntityLength();
     getFileEntry()->setLength(totalLength);
     if(getFileEntry()->getPath().empty()) {
@@ -240,6 +281,19 @@ bool HttpResponseCommand::executeInternal()
       return handleDefaultEncoding(httpResponse);
     }
   } else {
+#ifdef ENABLE_MESSAGE_DIGEST
+    if(!getDownloadContext()->getHashType().empty() &&
+       httpHeader->defined(HttpHeader::DIGEST)) {
+      std::vector<Checksum> checksums;
+      httpResponse->getDigest(checksums);
+      for(std::vector<Checksum>::iterator i = checksums.begin(),
+            eoi = checksums.end(); i != eoi; ++i) {
+        if(checkChecksum(getDownloadContext(), *i)) {
+          break;
+        }
+      }
+    }
+#endif // ENABLE_MESSAGE_DIGEST
     // validate totalsize
     getRequestGroup()->validateTotalLength(getFileEntry()->getLength(),
                                        httpResponse->getEntityLength());
@@ -385,9 +439,10 @@ bool HttpResponseCommand::handleOtherEncoding
     getRequestGroup()->initPieceStorage();
     getPieceStorage()->markAllPiecesDone();
     getDownloadContext()->setChecksumVerified(true);
-    A2_LOG_NOTICE(fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                      util::itos(getRequestGroup()->getGID()).c_str(),
-                      getRequestGroup()->getFirstFilePath().c_str()));
+    A2_LOG_NOTICE
+      (fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
+           util::itos(getRequestGroup()->getGID()).c_str(),
+           getRequestGroup()->getFirstFilePath().c_str()));
     poolConnection();
     return true;
   }
@@ -500,4 +555,21 @@ void HttpResponseCommand::onDryRunFileFound()
   poolConnection();
 }
 
+#ifdef ENABLE_MESSAGE_DIGEST
+bool HttpResponseCommand::checkChecksum
+(const SharedHandle<DownloadContext>& dctx,
+ const Checksum& checksum)
+{
+  if(dctx->getHashType() == checksum.getHashType()) {
+    if(dctx->getDigest() == checksum.getDigest()) {
+      A2_LOG_INFO("Valid hash found in Digest header field.");
+      return true;
+    } else {
+      throw DL_ABORT_EX("Invalid hash found in Digest header field.");
+    }
+  }
+  return false;
+}
+#endif // ENABLE_MESSAGE_DIGEST
+
 } // namespace aria2
