@@ -44,6 +44,8 @@
 #include "FileEntry.h"
 #include "BitfieldMan.h"
 #include "DownloadContext.h"
+#include "LogFactory.h"
+#include "fmt.h"
 
 namespace aria2 {
 
@@ -61,11 +63,7 @@ IteratableChecksumValidator::IteratableChecksumValidator
 
 IteratableChecksumValidator::~IteratableChecksumValidator()
 {
-#ifdef HAVE_POSIX_MEMALIGN
-  free(buffer_);
-#else // !HAVE_POSIX_MEMALIGN
   delete [] buffer_;
-#endif // !HAVE_POSIX_MEMALIGN
 }
 
 void IteratableChecksumValidator::validateChunk()
@@ -77,10 +75,12 @@ void IteratableChecksumValidator::validateChunk()
     ctx_->update(buffer_, length);
     currentOffset_ += length;
     if(finished()) {
-      std::string actualChecksum = ctx_->hexDigest();
-      if(dctx_->getChecksum() == actualChecksum) {
+      std::string actualDigest = ctx_->hexDigest();
+      if(dctx_->getDigest() == actualDigest) {
         pieceStorage_->markAllPiecesDone();
       } else {
+        A2_LOG_INFO(fmt("Checksum validation failed. expected=%s, actual=%s",
+                        dctx_->getDigest().c_str(), actualDigest.c_str()));
         BitfieldMan bitfield(dctx_->getPieceLength(), dctx_->getTotalLength());
         pieceStorage_->setBitfield(bitfield.getBitfield(), bitfield.getBitfieldLength());
       }
@@ -91,7 +91,6 @@ void IteratableChecksumValidator::validateChunk()
 bool IteratableChecksumValidator::finished() const
 {
   if((uint64_t)currentOffset_ >= dctx_->getTotalLength()) {
-    pieceStorage_->getDiskAdaptor()->disableDirectIO();
     return true;
   } else {
     return false;
@@ -105,17 +104,10 @@ uint64_t IteratableChecksumValidator::getTotalLength() const
 
 void IteratableChecksumValidator::init()
 {
-#ifdef HAVE_POSIX_MEMALIGN
-  free(buffer_);
-  buffer_ = reinterpret_cast<unsigned char*>
-    (util::allocateAlignedMemory(ALIGNMENT, BUFSIZE));
-#else // !HAVE_POSIX_MEMALIGN
   delete [] buffer_;
   buffer_ = new unsigned char[BUFSIZE];
-#endif // !HAVE_POSIX_MEMALIGN
-  pieceStorage_->getDiskAdaptor()->enableDirectIO();
   currentOffset_ = 0;
-  ctx_ = MessageDigest::create(dctx_->getChecksumHashAlgo());
+  ctx_ = MessageDigest::create(dctx_->getHashType());
 }
 
 } // namespace aria2
