@@ -52,28 +52,16 @@
 
 namespace aria2 {
 
-unsigned int PeerListenCommand::numInstance_ = 0;
-
-PeerListenCommand* PeerListenCommand::instance_ = 0;
-
-PeerListenCommand* PeerListenCommand::instance6_ = 0;
-
 PeerListenCommand::PeerListenCommand
 (cuid_t cuid,
  DownloadEngine* e,
  int family)
   : Command(cuid),
     e_(e),
-    family_(family),
-    lowestSpeedLimit_(20*1024)
-{
-  ++numInstance_;
-}
+    family_(family)
+{}
 
-PeerListenCommand::~PeerListenCommand()
-{
-  --numInstance_;
-}
+PeerListenCommand::~PeerListenCommand() {}
 
 bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
 {
@@ -82,7 +70,7 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
   std::vector<int32_t> randPorts = seq.flush();
   std::random_shuffle(randPorts.begin(), randPorts.end(),
                       *SimpleRandomizer::getInstance().get());
-  
+  const int ipv = (family_ == AF_INET) ? 4 : 6;
   for(std::vector<int32_t>::const_iterator portItr = randPorts.begin(),
         eoi = randPorts.end(); portItr != eoi; ++portItr) {
     if(!(0 < (*portItr) && (*portItr) <= 65535)) {
@@ -93,13 +81,11 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
       socket_->bind(A2STR::NIL, port, family_);
       socket_->beginListen();
       socket_->setNonBlockingMode();
-      A2_LOG_NOTICE(fmt("IPv%d BitTorrent: listening to port %d",
-                        family_ == AF_INET?4:6, port));
+      A2_LOG_NOTICE(fmt("IPv%d BitTorrent: listening to port %u", ipv, port));
       return true;
     } catch(RecoverableException& ex) {
-      A2_LOG_ERROR_EX(fmt(MSG_BIND_FAILURE,
-                          getCuid(), port),
-                      ex);
+      A2_LOG_ERROR_EX(fmt("IPv%d BitTorrent: failed to bind port %u",
+                          ipv, port), ex);
       socket_->closeConnection();
     }
   }
@@ -150,21 +136,4 @@ bool PeerListenCommand::execute() {
   return false;
 }
 
-PeerListenCommand* PeerListenCommand::getInstance(DownloadEngine* e, int family)
-{
-  if(family == AF_INET) {
-    if(!instance_) {
-      instance_ = new PeerListenCommand(e->newCUID(), e, family);
-    }
-    return instance_;
-  } else if(family == AF_INET6) {
-    if(!instance6_) {
-      instance6_ = new PeerListenCommand(e->newCUID(), e, family);
-    }
-    return instance6_;
-  } else {
-    return 0;
-  }
-}
-
 } // namespace aria2
