@@ -86,6 +86,21 @@ inline uint64_t ntoh64(uint64_t x) { return byteswap64(x); }
 inline uint64_t hton64(uint64_t x) { return byteswap64(x); }
 #endif // !WORDS_BIGENDIAN
 
+#ifdef __MINGW32__
+std::wstring utf8ToWChar(const std::string& src);
+
+std::wstring utf8ToWChar(const char* str);
+
+std::string utf8ToNative(const std::string& src);
+
+std::string wCharToUtf8(const std::wstring& wsrc);
+
+std::string nativeToUtf8(const std::string& src);
+#else // !__MINGW32__
+# define utf8ToWChar(src) src
+# define utf8ToNative(src) src
+#endif // !__MINGW32__
+
 namespace util {
 
 void divide
@@ -157,6 +172,8 @@ std::string percentEncode(const unsigned char* target, size_t len);
 
 std::string percentEncode(const std::string& target);
 
+std::string percentEncodeMini(const std::string& target);
+
 bool inRFC3986ReservedChars(const char c);
 
 bool inRFC3986UnreservedChars(const char c);
@@ -246,19 +263,22 @@ int64_t getRealSize(const std::string& sizeWithUnit);
 
 std::string abbrevSize(int64_t size);
 
-template<typename InputIterator>
+template<typename InputIterator, typename Output>
 void toStream
-(InputIterator first, InputIterator last, std::ostream& os)
+(InputIterator first, InputIterator last, Output& os)
 {
-  os << _("Files:") << "\n";
-  os << "idx|path/length" << "\n";
-  os << "===+===========================================================================" << "\n";
+  os.printf("%s\n"
+            "idx|path/length\n"
+            "===+===========================================================================\n", _("Files:"));
   int32_t count = 1;
   for(; first != last; ++first, ++count) {
-    os << std::setw(3) << count << "|" << (*first)->getPath() << "\n";
-    os << "   |" << util::abbrevSize((*first)->getLength()) << "B ("
-       << util::uitos((*first)->getLength(), true) << ")\n";
-    os << "---+---------------------------------------------------------------------------" << "\n";
+    os.printf("%3d|%s\n"
+              "   |%sB (%s)\n"
+              "---+---------------------------------------------------------------------------\n",
+              count,
+              (*first)->getPath().c_str(),
+              util::abbrevSize((*first)->getLength()).c_str(),
+              util::uitos((*first)->getLength(), true).c_str());
   }
 }
 
@@ -415,6 +435,7 @@ bool getCidrPrefix(struct in_addr& in, const std::string& ip, int bits);
 bool inSameCidrBlock(const std::string& ip1, const std::string& ip2, int bits);
 
 void removeMetalinkContentTypes(const SharedHandle<RequestGroup>& group);
+void removeMetalinkContentTypes(RequestGroup* group);
 
 // No throw
 void executeHookByOptName
@@ -437,6 +458,60 @@ std::string makeString(const char* str);
 // strerror returns NULL, this function returns empty string.
 std::string safeStrerror(int errNum);
 
+// Parses sequence [first, last) and find name=value pair delimited by
+// delim character. If name(and optionally value) is found, returns
+// pair of iterator which can use as first parameter of next call of
+// this function, and true. If no name is found, returns the pair of
+// last and false.
+template<typename Iterator>
+std::pair<Iterator, bool>
+nextParam
+(std::string& name,
+ std::string& value,
+ Iterator first,
+ Iterator last,
+ char delim)
+{
+  Iterator end = last;
+  while(first != end) {
+    last = first;
+    Iterator parmnameFirst = first;
+    Iterator parmnameLast = first;
+    bool eqFound = false;
+    for(; last != end; ++last) {
+      if(*last == delim) {
+        break;
+      } else if(!eqFound && *last == '=') {
+        eqFound = true;
+        parmnameFirst = first;
+        parmnameLast = last;
+      }
+    }
+    std::string tname, tvalue;
+    if(parmnameFirst == parmnameLast) {
+      if(!eqFound) {
+        parmnameFirst = first;
+        parmnameLast = last;
+        tname = util::stripIter(parmnameFirst, parmnameLast);
+      }
+    } else {
+      first = parmnameLast+1;
+      tname = util::stripIter(parmnameFirst, parmnameLast);
+      tvalue = util::stripIter(first, last);
+    }
+    if(last != end) {
+      ++last;
+    }
+    if(!tname.empty()) {
+      name.swap(tname);
+      value.swap(tvalue);
+      return std::make_pair(last, true);
+    }
+    first = last;
+  }
+  return std::make_pair(end, false);
+}
+
 } // namespace util
 
 } // namespace aria2
